@@ -1,4 +1,4 @@
-__all__ = ('BankCardPoint', 'BankCard3dsPoint')
+__all__ = ('BankCardPoint', 'BankCard3dsPoint', 'ActivatePoint')
 
 from expressmoney.api import *
 
